Module approx

Module approx 

Floating-point comparison helpers for approximate numerical work.

Functions

approx_eq
Returns true when a and b are within an absolute epsilon.
clamp_epsilon
Normalizes an epsilon to a non-negative finite value.
relative_eq
Returns true when a and b are within a relative epsilon.