bisection_interval

Function bisection_interval 

pub fn bisection_interval<F>(
    f: F,
    interval: Interval<f64>,
    options: RootOptions,
) -> Result<f64, RootError>
where F: Fn(f64) -> f64,
Finds a root with the bisection method over a bounded use-interval interval.

Unbounded and empty intervals return RootError::InvalidInterval. Open endpoints participate in bracketing, but only closed endpoints are eligible for the immediate endpoint-root fast path.