Module root

Module root 

Iterative approximate root-finding helpers.

Structs

RootOptions
Configuration for iterative approximate root finders.

Enums

RootError
Failure modes for approximate iterative root finders.

Functions

bisection
Finds a root with the bisection method on a bracketing interval.
bisection_interval
Finds a root with the bisection method over a bounded use-interval interval.
newton_raphson
Finds a root with Newton-Raphson iteration.